package googlesearch;

import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

/*
 * Created on Apr 12, 2006
 * 
 * @author jbergin
 *
 */

/** An abstract class representing queries that contain one or more other queries. It's main responsibility is to
 * walk a tree of query objects and build up the query string represented by the tree. 
 * @author jbergin
 *
 */
public abstract class CompositeQuery extends Query
{
    public String getSearchString()
    {
        ArrayList<Query> start = new ArrayList<Query>();
        ArrayList<Query> finish = new ArrayList<Query>();
        String baseString = buildSearchString(start, finish);
        validatePreModifiers(start);
        validatePostModifiers(finish);
        Iterator<Query> iter = start.iterator();
        while (iter.hasNext())
        {
            baseString = iter.next().modifier() + baseString;
        }
        iter = finish.iterator();
        while (iter.hasNext())
        {
            baseString = baseString + iter.next().modifier();
        }
        return baseString;
    }

    /**
     * Validate the pre queries <br>
     * Rules validated so far: <br>
     * none
     * 
     * @param queries
     *            the queries to be validated
     */
    private static void validatePreModifiers(List<Query> queries)
    {

    }

    /**
     * Validate that all of the post queries are valid. <br>
     * The rules so far are: <br>
     * there can be only one site: phrase in a query. The first found is used.
     * The others removed.
     * 
     * @param queries
     *            The queries to be validated
     */
    private static void validatePostModifiers(List<Query> queries)
    {
        boolean sawSite = false;
        Iterator<Query> iter = queries.iterator();
        while (iter.hasNext())
        {
            Query query = iter.next();
            if(query instanceof SiteQuery)
            {
                if(sawSite)
                {
                    iter.remove();
                }
                sawSite = true;

            }
        }
    }

}
