package googlesearch;

import java.util.List;

/*
 * Created on Apr 12, 2006
 * 
 * @author jbergin
 *
 */

/**
 * Transforms any query into one that searches for the exact phrase in the given
 * query, rather than searching for the words individually.
 * 
 * @author jbergin
 * 
 */
public class ExactQuery extends CompositeQuery
{
    public ExactQuery(Query query)
    {
        this.decorated = query;
    }

    public String buildSearchString(List<Query> start, List<Query> finish)
    {
        String decoratedString = decorated.buildSearchString(start, finish);
        if(isExact(decoratedString))
        {
            return decoratedString;
        }
        return "\"" + decoratedString + "\"";
    }

    /**
     * Is the current search string already an exact search?
     * 
     * @return true if the search is already exact
     */
    public static boolean isExact(String query)
    {
         query = query.trim(); 
         return query.indexOf("\"") == 0
                && query.lastIndexOf("\"") == query.length() - 1;
    }

    /** Strip the delimiting quotes off a string. Used by DefinitionQuery.
     * @param query any string
     * @return the string without delimiting quotes
     */
    public static String stripQuotes(String query)
    {
        if(isExact(query))
        {
            return query.substring(1, query.length()-1);
        }
        return query;
    }

    private final Query decorated;

}
