package googlesearch;

import java.util.List;

/*
 * Created on Apr 12, 2006
 * 
 * @author jbergin
 *
 */

/**
 * A query that specifies things that should not appear on the page. Note that a
 * not query here is always exact.
 * 
 * @author jbergin
 * 
 */
public class NotQuery extends CompositeQuery
{
    /**
     * Create a query of the form left -notPart.
     * 
     * @param left
     *            the basic query to be modified
     * @param notPart
     *            the keyword phrase to be excluded.
     */
    public NotQuery(Query left, Query notPart)
    {
        this.left = left;
        this.notPart = new ExactQuery(notPart); // in case there are many words.
    }

    public String buildSearchString(List<Query> start, List<Query> finish)
    {
        String leftString = left.buildSearchString(start, finish);
        String rightString = notPart.buildSearchString(start, finish).trim();
        return leftString + " -" + rightString;
    }

    private final Query left;

    private final Query notPart;
}
