package googlesearch;

import java.util.List;

/*
 * Created on Apr 12, 2006
 * 
 * @author jbergin
 *
 */

/** Represents a query that will find pages that contain the one word OR another (or both). Normally Google requires 
 * a page to have all the words in a query as in an AND query. 
 * @author jbergin
 *
 */
public class OrQuery extends CompositeQuery
{
	/** Create an OR query. The words of the left query OR those of the right: "Joseph" OR "Bergin" without requiring both 
     * Words. Normally left and right are Simple Queries. 
	 * @param left the term to the left of the OR logical operator
	 * @param right the search term to the right of the operator. 
	 */
	public OrQuery(Query left, Query right)
	{	
		this.left = left;
		this.right = right;
	}

	public String buildSearchString(List<Query> start, List<Query> finish)
	{
		String leftString = left.buildSearchString(start, finish);
		String rightString = right.buildSearchString(start, finish);
		return leftString + " OR " + rightString;
	}
	
	private final Query left;
	private final Query right;
}
