/*
 * Created on Apr 13, 2006
 * 
 * @author jbergin
 *
 */
package googlesearch;
import java.util.HashMap;
import java.util.Iterator;

/** A storage mechanism for queries. Queries are stored with a user-supplied name. The name can be later used
 * to retrieve a query. 
 * @author jbergin
 *
 */
public class QueryStore
{

	/** Insert a query into the storage tagged with a name of your choosing. You can retrieve the query 
	 * later by using the same name. Single word names without punctuation are preferred as they are
	 * a bit safer in use. 
	 * @param key a name of your choosing to use as the retrieval key
	 * @param query the query to be saved 
	 */
	public void put(String key, Query query)
	{
		if(key != null && !key.equals("") && query != null)
		{
			store.put(key, query);
		}
	}
	
	/** Retrieve a query with a given "name" or the NULL_QUERY if no query with the name is stored
	 * @param key the "key" used when a query was stored
	 * @return the Query associated with this name or the NULL_QUERY if there is no such
	 */
	public Query get(String key)
	{
		Query result = store.get(key);
		if(result == null)
		{
			return Query.NULL_QUERY;
		}
		return result;
	}
	
	/** Remove a given query from the storage
	 * @param key the name of the query to be removed
	 */
	public void remove(String key)
	{
		//TODO remove the object with this key if it is present.
	}
	
	/** Remove all the queries from the storage. Empty the storage. 
	 * 
	 */
	public void clear()
	{
		//TODO clear the storage of all Queries. 
	}
	
	/** Obtain an iterator over the keys. 
	 * @return an iterator that will return all the keys in the storage
	 */
	public Iterator<String> keys()
	{
		return store.keySet().iterator();
	}
	
	/** Obtain an iterator over all the Queries in the storage
	 * @return an iterator that will return all the queries in the storage. 
	 */
	public Iterator<Query> values()
	{
		return store.values().iterator();
	}

	private final HashMap<String, Query> store = new HashMap<String, Query>();
}
