/*
 * Created on Apr 13, 2006
 * 
 * @author jbergin
 *
 */
package googlesearch;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.ArrayList;
import java.util.Collection;

/** A storage mechanism for the result pages returned by queries. Allows you to save some of the results for later without
 * running the search again. This is a multi-map. For one key (a Query) you can save several results. 
 * @author jbergin
 *
 */
public class ResultPageStore
{
	/** 	Insert a page into storage with a query as key. Several pages may be stored with the
	 * same query. They are maintained in a list in the order inserted. 
	 * @param key a query used to tag the saved page
	 * @param page a page to save
	 */
	public void put(Query key, SearchResultPage page)
	{
		if(key != null  && page != null)
		{
			List<SearchResultPage> where = store.get(key);
			if(where == null)
			{
				where = new ArrayList<SearchResultPage>();
				store.put(key, where);
			}
			where.add( page);			
		}
	}
	
	/** Put all of the pages into the storage with the given key
	 * @param key the retrieval key used to get the pages back
	 * @param pages the pages to store with this key
	 */
	public void put(Query key, Collection pages)
	{
		//TODO don't forget to assure that only pages are inserted. 
	}

	/** Remove a single page from the storage by key. Does nothing if the page isn't in the storage with this key.
	 * @param key the key used to store the page
	 * @param page the page to be removed.
	 */
	public void remove(Query key, SearchResultPage page)
	{
		//TODO remove this one page from the storage if it is there with this key.
	}
	
	/** Remove all the pages with a given key
	 * @param key the key whose pages should be removed. 
	 */
	public void remove(Query key)
	{
		//TODO remove all pages with this key if any are stored. 
	}
	
	public void clear()
	{
		//TODO clear the storage of all values. 
	}
	
	/** Retrieve a List of the pages stored associated with this Query
	 * @param key the Query whose pages were previously stored
	 * @return a List (possibly empty) of pages store with the key
	 */
	public List<SearchResultPage> get(Query key)
	{
		List result = store.get(key);
		if(result == null)
		{
			return new ArrayList();
		}
		return result;
	}
	
	/** Obtain an iterator over the keys used in the storage
	 * @return an iterator over the keys
	 */
	public Iterator<Query> keys()
	{
		return store.keySet().iterator();
	}
	
	/** Obtain an iterator over the values stored. The iterator will return List<SearchResultPage> objects
	 * @return an iterator over the lists of values. 
	 */
	public Iterator<List<SearchResultPage>> values()
	{
		return store.values().iterator();
	}

	private final HashMap<Query, List<SearchResultPage>> store = new HashMap<Query, List<SearchResultPage>>();

}
