package googlesearch;

/*
 * Created on Apr 12, 2006
 * 
 * @author jbergin
 *@version V2
 */

import java.util.List;

/**
 * Encapsulates Google search queries as objects. The search string can be as
 * simple as a single word, or it can include any of the special features of the
 * Google advanced search specification. Note that simple searches (words) can
 * be combined using other objects in the package. 
 * 
 * <p> Structurally, these are the leaves of a query tree and the base case of the recursion that processes
 * those trees. 
 * 
 * @author jbergin
 * 
 */
public class SimpleQuery extends Query
{
    /** Create a google query with a given search string, usually just a single word. 
     * @param searchString the Google search string. 
     */
    public SimpleQuery(String searchString)
    {
        this.searchString = searchString.trim();
    }

    public String buildSearchString(List<Query> start, List<Query> finish)
    {
        return searchString;
    }

    public String getSearchString()
    {
        return searchString; 
    }

    private final String searchString;

}
