/*
 * Created on Apr 14, 2006
 * 
 * @author jbergin
 *
 */
package googlesearch;

import java.net.URL;
import java.net.MalformedURLException;
import java.util.List;

/**
 * A decorator for querys to search a specific site like www.google.com. Note
 * that if you attempt to apply several site queries, to a base query, only the
 * first will be effective. ("First" means the first found in a postorder search
 * of the query object tree.)
 * 
 * @author jbergin
 * 
 */
public class SiteQuery extends CompositeQuery
{
    /**
     * Create a query that applies a site search to a given query
     * 
     * @param baseQuery
     *            the terms to search for
     * @param site
     *            the single site to search. This should be a complete site
     *            name. e.g. www.google.com.
     */
    public SiteQuery(Query baseQuery, String site)
    {
        this.decorated = baseQuery;
        this.site = site.trim();
    }

    public String modifier()
    {
        return " site:" + site;
    }

    public String buildSearchString(List<Query> start, List<Query> finish)
    {
        String decoratedString = decorated.buildSearchString(start, finish);
        finish.add(this);
        return decoratedString;
    }

    private final Query decorated;

    private final String site;

    /**
     * Determine if a site string creates a well formed URL.You can use this
     * before creating a SiteQuery to check your site string. Note that it does
     * not check that the site exists, only that the URL is well formed.
     * 
     * @param site
     *            the site string to check
     * @return true if the site url is well formed
     */
    public static boolean validateSite(String site)
    {
        try
        {
            new URL("http://" + site);
            return true;
        }
        catch (MalformedURLException m)
        {
            return false;
        }
    }
}
